@@ -9,7 +9,7 @@ from gt_lib.macd import macd
 from gt_lib.reversal import reversal
 from gt_lib.rsi import rsi
 from gt_lib.atr import atr
-from gt_lib.trailig_stop_loss import t_stop_loss
+from gt_lib.trailing_stop_loss import t_stop_loss
 from gt_lib.double_ema import double_ema
 from gt_lib.money_flow_index import mfi
 from gt_lib.fractal import fractal
